GoFeatureFlagProvider class

GoFeatureFlagProvider integrates with the Intellitoggle service. Provides implementation for all DSFeatureFlagProvider methods.

Constructors

GoFeatureFlagProvider({required String apiUrl, required String apiKey})
Constructor to initialize the GoFeatureFlagProvider. apiUrl: The base URL for the Intellitoggle API. apiKey: The API key for authentication.

Properties

apiKey → String
final
apiUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluateFlag(String flagKey, {Map<String, dynamic>? context}) → Future<DSFeatureFlagEvaluationResult>
Evaluates a feature flag and returns detailed evaluation results.
override
getBooleanFlag(String flagKey, {bool defaultValue = false, Map<String, dynamic>? context}) → Future<bool>
Fetches the value of a feature flag as a boolean.
override
getJsonFlag(String flagKey, {Map<String, dynamic> defaultValue = const {}, Map<String, dynamic>? context}) → Future<Map<String, dynamic>>
Fetches the value of a feature flag as JSON.
override
getNumberFlag(String flagKey, {num defaultValue = 0, Map<String, dynamic>? context}) → Future<num>
Fetches the value of a feature flag as a number.
override
getStringFlag(String flagKey, {String defaultValue = '', Map<String, dynamic>? context}) → Future<String>
Fetches the value of a feature flag as a string.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited