DSIntelliToggleErrorMapper class
Maps IntelliToggle and OpenFeature errors to DartStream-compatible exceptions.
Ensures consistent error handling across the DartStream framework regardless of the underlying feature flag provider.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
mapError(
dynamic error) → DSIntelliToggleException - Maps an error to a DSIntelliToggleException.