DSIntelliToggleException class

Exception class for IntelliToggle-specific errors.

Implemented types

Constructors

DSIntelliToggleException({required String code, required String message})
Creates a DSIntelliToggleException.
const

Properties

code → String
Error code identifying the type of error.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Human-readable error message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited