DSIntelliToggleConfig class
Configuration options for the DSIntelliToggleProvider.
Provides sensible defaults and supports both production and development environment presets.
Example usage:
// Production config
final config = DSIntelliToggleConfig.production();
// Development config
final config = DSIntelliToggleConfig.development();
// Custom config
final config = DSIntelliToggleConfig(
enableLogging: true,
pollingInterval: Duration(minutes: 2),
);
Constructors
- DSIntelliToggleConfig({Uri? baseUri, Duration? timeout, bool? enablePolling, Duration? pollingInterval, bool? enableStreaming, int? maxRetries, bool? enableLogging})
- Creates a custom DSIntelliToggleConfig.
- DSIntelliToggleConfig.development({Uri? baseUri, Duration? timeout})
-
Development preset configuration.
factory
- DSIntelliToggleConfig.production({Duration? timeout, Duration? pollingInterval})
-
Production preset configuration.
factory
Properties
- baseUri → Uri
-
API base URL for IntelliToggle service.
final
- enableLogging → bool
-
Enables verbose debug logging for troubleshooting.
final
- enablePolling → bool
-
Whether to poll periodically for configuration changes.
final
- enableStreaming → bool
-
Enables real-time updates from the service if supported.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxRetries → int
-
Number of retry attempts for failed requests.
final
- pollingInterval → Duration
-
How often to poll for updates when polling is enabled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
Maximum request duration before failing.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toIntelliToggleOptions(
) → IntelliToggleOptions - Converts to IntelliToggleOptions for the official SDK.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited