DSIntelliToggleEventHandler class
Handles lifecycle events emitted by the IntelliToggle provider.
Listens to provider events such as readiness, configuration changes, and errors, and maps them to DartStream-compatible callbacks.
Example usage:
final eventHandler = DSIntelliToggleEventHandler(provider: provider);
eventHandler.initialize();
Constructors
-
DSIntelliToggleEventHandler({required IntelliToggleProvider provider, void onReady()?, void onConfigurationChanged(List<
String> flagsChanged)?, void onError(String message)?}) - Creates a DSIntelliToggleEventHandler.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onConfigurationChanged
↔ void Function(List<
String> flagsChanged)? -
Callback triggered when flags are updated.
getter/setter pair
- onError ↔ void Function(String message)?
-
Callback triggered when an error occurs.
getter/setter pair
- onReady ↔ void Function()?
-
Callback triggered when the provider is ready.
getter/setter pair
- provider → IntelliToggleProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initialize(
) → void - Initializes event listeners for the IntelliToggle provider. Initializes event listeners for the IntelliToggle provider. Initializes event listeners for the IntelliToggle provider.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited